﻿using System;
using System.Data.OleDb;

using DevExpress.Data;
using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 연결
        /// </summary>
        private OleDbConnection connection;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.connection = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=nwind.mdb");

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowFooter = true;

            this.gridControl.DataSource = Product.GetProductList(this.connection);

            GridColumnSummaryItem unitPriceSummaryItem  = new GridColumnSummaryItem();

            unitPriceSummaryItem.FieldName     = "UnitPrice";
            unitPriceSummaryItem.SummaryType   = SummaryItemType.Max;
            unitPriceSummaryItem.DisplayFormat = "최고액 : {0:c2}";

            this.gridView.Columns["UnitPrice"].Summary.Add(unitPriceSummaryItem);

            this.gridView.BestFitColumns();

            this.executeButton.Click += executeButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 실행 버튼 클릭시 처리하기 - executeButton_Click(sender, e)

        /// <summary>
        /// 실행 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void executeButton_Click(object sender, EventArgs e)
        {
            GridSummaryItemCollection gridSummaryItemCollection = this.gridView.Columns[0].SummaryItem.Collection;

            gridSummaryItemCollection.BeginUpdate();

            try
            {
                GridSummaryItem gridSummaryItem = this.gridView.Columns["UnitPrice"].SummaryItem;

                gridSummaryItem.SummaryType   = SummaryItemType.Count;
                gridSummaryItem.FieldName     = "UnitPrice";
                gridSummaryItem.DisplayFormat = "건수 : {0:n0}";
            }
            finally
            {
                gridSummaryItemCollection.EndUpdate();
            }
        }

        #endregion
    }
}